@@ -10,8 +10,6 @@ use HTTP::Request ();
 use IO::Socket::INET ();
 use IO::Select ();
 
-use IO::Framed ();
-
 use FindBin;
 use lib "$FindBin::Bin/../lib";
 
@@ -37,13 +35,6 @@ my $server = IO::Socket::INET->new(
     Listen => 2,
 );
 
-#This is a “lazy” example. A more robust, production-level
-#solution would not need to fork() unless there were privilege
-#drops or some such that necessitate separate processes per session.
-
-#For an example of a non-forking server in Perl, look at Net::WAMP’s
-#router example.
-
 while ( my $sock = $server->accept() ) {
     fork and next;
 
@@ -53,9 +44,7 @@ while ( my $sock = $server->accept() ) {
 
     NWDemo::set_signal_handlers_for_server($sock);
 
-    my $framed_obj = IO::Framed->new($sock);
-
-    my $parser = Net::WebSocket::Parser->new($framed_obj);
+    my $parser = Net::WebSocket::Parser->new($sock);
 
     $sock->blocking(0);
 
@@ -65,22 +54,22 @@ while ( my $sock = $server->accept() ) {
 
     my $ept = Net::WebSocket::Endpoint::Server->new(
         parser => $parser,
-        out => $framed_obj,
+        out => $sock,
     );
-    $ept->do_not_die_on_close();
 
     my $streamer = Net::WebSocket::Streamer::Server->new('text');
 
     my $cur_number = 0;
 
     while (!$ept->is_closed()) {
-        my ( $rdrs_ar, undef, $errs_ar ) = IO::Select->select( $s, undef, $s, 0 );
+        my ( $rdrs_ar, $s, $errs_ar ) = IO::Select->select( $s, $s, $s, 1 );
 
         my $is_final = ($cur_number == 2);
 
         my $method = $is_final ? 'create_final' : 'create_chunk';
 
-        $framed_obj->write(
+        syswrite(
+            $sock,
             $streamer->$method($cur_number)->to_bytes(),
         );
 
@@ -97,7 +86,15 @@ while ( my $sock = $server->accept() ) {
         }
 
         if ( $rdrs_ar && @$rdrs_ar ) {
-            $ept->get_next_message();   #we don’t care what it is
+            try {
+                $ept->get_next_message();   #we don’t care what it is
+            }
+            catch {
+                if (!try { $_->isa('Net::WebSocket::X::ReceivedClose') } ) {
+                    local $@ = $_;
+                    die;
+                }
+            };
         }
 
         sleep 1;
